@@ -54,6 +54,7 @@ The infinite set of all posets can be used to find minimal examples::
     :meth:`~Posets.RandomPoset` | Return a random poset on `n` elements.
     :meth:`~Posets.RibbonPoset` | Return a ribbon on `n` elements with descents at `descents`.
     :meth:`~Posets.RestrictedIntegerPartitions` | Return the poset of integer partitions of `n`, ordered by restricted refinement.
+    :meth:`~Posets.Sashes` | Return the lattice of sashes of `n`.
     :meth:`~Posets.SetPartitions` | Return the poset of set partitions of the set `\{1,\dots,n\}`.
     :meth:`~Posets.ShardPoset` | Return the shard intersection order.
     :meth:`~Posets.ShufflePoset` | Return the Shuffle lattice for `(m,n)`.
@@ -104,7 +105,7 @@ from sage.misc.classcall_metaclass import ClasscallMetaclass
 import sage.categories.posets
 from sage.combinat.permutation import Permutations, Permutation, to_standard
 from sage.combinat.posets.posets import Poset, FinitePoset, FinitePosets_n
-from sage.combinat.posets import bubble_shuffle, hochschild_lattice
+from sage.combinat.posets import bubble_shuffle, hochschild_lattice, sashes
 from sage.combinat.posets.d_complete import DCompletePoset
 from sage.combinat.posets.mobile import MobilePoset as Mobile
 from sage.combinat.posets.lattices import (LatticePoset, MeetSemilattice,
@@ -283,7 +284,7 @@ class Posets(metaclass=ClasscallMetaclass):
                          for y in range(n) if v & (1 << y) == 0]
                      for v in range(2**n)})
         return FiniteLatticePoset(hasse_diagram=D,
-                                  category=FiniteLatticePosets(),
+                                  category=FiniteLatticePosets().Stone(),
                                   facade=facade)
 
     BubblePoset = staticmethod(bubble_shuffle.BubblePoset)
@@ -292,6 +293,8 @@ class Posets(metaclass=ClasscallMetaclass):
 
     HochschildLattice = staticmethod(hochschild_lattice.hochschild_lattice)
 
+    Sashes = staticmethod(sashes.lattice_of_sashes)
+
     @staticmethod
     def ChainPoset(n, facade=None):
         r"""
@@ -334,7 +337,7 @@ class Posets(metaclass=ClasscallMetaclass):
         D = DiGraph([range(n), [[x, x + 1] for x in range(n - 1)]],
                     format='vertices_and_edges')
         return FiniteLatticePoset(hasse_diagram=D,
-                                  category=FiniteLatticePosets(),
+                                  category=FiniteLatticePosets().Stone(),
                                   facade=facade)
 
     @staticmethod
@@ -415,7 +418,8 @@ class Posets(metaclass=ClasscallMetaclass):
             sage: posets.DiamondPoset(5).is_distributive()
             False
         """
-        return LatticePoset([[1, 2], [4], [3], [4], []], facade=facade)
+        return LatticePoset([[1, 2], [4], [3], [4], []], facade=facade,
+                            category=FiniteLatticePosets().CongruenceUniform())
 
     @staticmethod
     def DiamondPoset(n, facade=None):
@@ -441,8 +445,10 @@ class Posets(metaclass=ClasscallMetaclass):
         c[0] = list(range(1, n - 1))
         c[n - 1] = []
         D = DiGraph({v: c[v] for v in range(n)}, format='dict_of_lists')
-        return FiniteLatticePoset(hasse_diagram=D,
-                                  category=FiniteLatticePosets(),
+        cat = FiniteLatticePosets().ChainGraded()
+        if n <= 4:
+            cat = cat.Stone()
+        return FiniteLatticePoset(hasse_diagram=D, category=cat,
                                   facade=facade)
 
     @staticmethod
@@ -510,7 +516,7 @@ class Posets(metaclass=ClasscallMetaclass):
         Div_n = divisors(n)
         hasse = DiGraph([Div_n, lambda a, b: b % a == 0 and is_prime(b // a)])
         return FiniteLatticePoset(hasse, elements=Div_n, facade=facade,
-                                  category=FiniteLatticePosets())
+                                  category=FiniteLatticePosets().Stone())
 
     @staticmethod
     def HessenbergPoset(H):
@@ -781,7 +787,8 @@ class Posets(metaclass=ClasscallMetaclass):
 
         def compare(a, b):
             return all(x <= y for x, y in zip(a, b))
-        return LatticePoset([elements, compare], facade=facade)
+        return LatticePoset([elements, compare], facade=facade,
+                            category=FiniteLatticePosets().Distributive())
 
     @staticmethod
     def RandomPoset(n, p):
@@ -1182,14 +1189,14 @@ class Posets(metaclass=ClasscallMetaclass):
         EXAMPLES::
 
             sage: posets.SymmetricGroupWeakOrderPoset(4)
-            Finite poset containing 24 elements
+            Finite lattice containing 24 elements
         """
         if n < 10 and labels == "permutations":
-            element_labels = dict([[s, "".join(map(str, s))]
-                                   for s in Permutations(n)])
+            element_labels = {s: "".join(map(str, s))
+                              for s in Permutations(n)}
         if n < 10 and labels == "reduced_words":
-            element_labels = dict([[s, "".join(map(str, s.reduced_word_lexmin()))]
-                                   for s in Permutations(n)])
+            element_labels = {s: "".join(map(str, s.reduced_word_lexmin()))
+                              for s in Permutations(n)}
         if side == "left":
 
             def weak_covers(s):
@@ -1200,6 +1207,7 @@ class Posets(metaclass=ClasscallMetaclass):
                 return [v for v in s.bruhat_succ() if
                         s.length() + (s.inverse().right_action_product(v)).length() == v.length()]
         else:
+
             def weak_covers(s):
                 r"""
                 Nested function for computing the covers of elements in the
@@ -1207,8 +1215,11 @@ class Posets(metaclass=ClasscallMetaclass):
                 """
                 return [v for v in s.bruhat_succ() if
                         s.length() + (s.inverse().left_action_product(v)).length() == v.length()]
-        return Poset(dict([[s, weak_covers(s)] for s in Permutations(n)]),
-                     element_labels)
+        return LatticePoset(
+            {s: weak_covers(s) for s in Permutations(n)},
+            element_labels, check=False,
+            category=FiniteLatticePosets().ChainGraded().Semidistributive()
+        )
 
     @staticmethod
     def TetrahedralPoset(n, *colors, **labels):
@@ -1277,12 +1288,10 @@ class Posets(metaclass=ClasscallMetaclass):
         elem_labels = {}
         if 'labels' in labels:
             if labels['labels'] == 'integers':
-                labelcount = 0
-                for (i, j, k) in elem:
-                    elem_labels[(i, j, k)] = labelcount
-                    labelcount += 1
+                for labelcount, ijk in enumerate(elem):
+                    elem_labels[ijk] = labelcount
         for c in colors:
-            for (i, j, k) in elem:
+            for i, j, k in elem:
                 if i + j + k < n - 1:
                     if c == 'green':
                         rels.append([(i, j, k), (i + 1, j, k)])
@@ -1643,7 +1652,7 @@ class Posets(metaclass=ClasscallMetaclass):
         edges.extend([(n, n + 1), (n, n + 2), (n + 1, n + 3), (n + 2, n + 3)])
         edges.extend((i, i + 1) for i in range(n + 3, 2 * n + 2))
         p = DiGraph([list(range(1, 2 * n + 3)), edges])
-        return DCompletePoset(p)
+        return DCompletePoset(p, category=FiniteLatticePosets().Distributive())
 
     @staticmethod
     def PermutationPattern(n):
@@ -2128,7 +2137,7 @@ def _random_distributive_lattice(n):
     return D
 
 
-def _random_stone_lattice(n):
+def _random_stone_lattice(n) -> DiGraph:
     """
     Return a random Stone lattice on `n` elements.
 
